Skip to contents

The purpose of this function is to provide a single function that will take a proteinGroups.txt produced by MaxQuant, perform the necessary data processing, and generate a volcano plot. This function will call the load_maxquant(), process_maxquant(), and volcano_plot_maxquant() functions in turn. The user will be asked to specify which groups are group 1 or group 2.

Usage

workflow_maxquant(...)

Arguments

...

ellipsis to allow the user to specify arguments for each function in the workflow. The accepted arguments for each function are as follows:

Value

A ggplot object containing the volcano plot generated from the MaxQuant data.

Examples

if (FALSE) { # \dontrun{
workflow_maxquant()
} # }