The purpose of this function is to provide a single function that will take a
proteinGroups.txt produced by MaxQuant, perform the necessary data
processing, and generate a volcano plot. This function will call the
load_maxquant(), process_maxquant(), and volcano_plot_maxquant()
functions in turn. The user will be asked to specify which groups are group 1
or group 2.
Arguments
- ...
ellipsis to allow the user to specify arguments for each function in the workflow. The accepted arguments for each function are as follows:
load_maxquant():file,datadir,cleanprocess_maxquant():group1,group2,meas,baseval,width,downshift,seed,var.equal,pairedvolcano_plot_maxquant():meas,threshold_p,threshold_fc,p_line,zero_line,x_line,vp_colours,groups,x_label,y_label,fsize